@@ -17,13 +17,13 @@
 
 !     ntdrec = number of time dependent records on disk.
 !               note: default case assumes 12 monthly S.B.C. records
-!                     (defined at the centers of the months) from
+!                     (defined at the centres of the months) from
 !                     the MOM climatological database.
 
 !     tdrec   = times at which the data records are defined.
-!               times are assumed to define the centers of the records.
+!               times are assumed to define the centres of the records.
 !               (ie: when using  monthly climatological data and the
-!                first record is january, "tdrec(1)" is defined in days
+!                first record is January, "tdrec(1)" is defined in days
 !                as day 15.5)
 
 !     aprec   = period lengths for the data records. (number of days
@@ -37,7 +37,7 @@
 !     dstamp   = time stamps marking the end of each S.B.C. data record
 
 !     period  = (true,false)  if the data records are to be treated as
-!               (perodic, not periodic). if periodic, then the model
+!               (periodic, not periodic). if periodic, then the model
 !               time is always mapped into the data records. if not,
 !               then record 1 is used for all model time before the
 !               beginning of the dataset and record "ntdrec" is used
@@ -67,16 +67,22 @@
 
       integer maxbcr, ntdbc
       parameter (maxbcr=12)
-      parameter (ntdbc = 3
+      parameter (ntdbc = 4
 # if defined restorst || defined uvic_replacst || defined uvic_read_my_stf
      &                 + 2
 # endif
-#if defined uvic_embm_astress
+#if defined uvic_embm_awind
      &                 + 1
 #endif
 # if defined uvic_embm_adv_q
      &                 + 2
 # endif
+# if defined uvic_embm_adv_t
+     &                 + 2
+# endif
+# if defined shortwave
+     &                 + 1
+# endif
 # if defined uvic_mtlm
      &                 + 1
 # endif
