@@ -52,14 +52,15 @@
 !     iodsp  = control # for writing diagnostic surface pressure
 !     iotsi  = control # for writing time step integrals
 !     ioxbt  = control # for writing time averaged xbt data
-!     iozmbc = control # for writing zonal mean surf boundary conditons
+!     iozmbc = control # for writing zonal mean surf boundary conditions
 
-!     iotext  = 120 character text string for describing the details
-!                of the next unformatted data record.
-!     expnam  = 60 character text string for the experiment name
+!     iotext    = 120 character text string for describing the details
+!                 of the next unformatted data record.
+!     expnam    = 60 character text string for the experiment name
+!     runstamp  = 120 character text string for the run stamp
 
 !     when writing unformatted data records in MOM, each data record is
-!     preceeded by a header record which was written as:
+!     proceeded by a header record which was written as:
 !     write(unit) stamp, iotext, expnam
 !     where stamp is a 32 character specification of the model date &
 !     time corresponding to the time step when the data was written and
@@ -72,7 +73,7 @@
 !      program decifr
 
 !-----------------------------------------------------------------------
-!      decifer an unformatted file from MOM by showing the header
+!      decipher an unformatted file from MOM by showing the header
 !      records. the file needs to copied to file "fort.21"
 !-----------------------------------------------------------------------
 
@@ -100,7 +101,7 @@
 
 !     note: all unformatted diagnostic MOM data is handled this way.
 !     to insure that data is read properly, verify that arrays are
-!     dimensioned corectly by comparing the listed variables against
+!     dimensioned correctly by comparing the listed variables against
 !     those in the *.h files. (grep -i -n "variable" *.h) Also, most
 !     data from MOM is written IEEE 32bit so it is read directly by
 !     most workstations. However, when trying to read these IEEE files
@@ -111,8 +112,8 @@
 !     also written as part of the data. Averaging periods = zero
 !     indicate instantaneous data.
 
-      character iotext*120, expnam*60
-      common /iounit_c/ iotext, expnam
+      character iotext*120, expnam*60, runstamp*120
+      common /iounit_c/ iotext, expnam, runstamp
 
       integer taum1disk, taudisk, taup1disk, latdisk, kflds
       integer iodoc, iostab, iotavg, iotmb, iotrmb, iotim, iotim1
