@@ -13,7 +13,8 @@
 !     nhreg  = number of regions in the horizontal used for averaging
 !              tracers.
 !     nvreg  = number of regions in the vertical used for term balance
-!              calculations. note "nvreg" isn`t used for tracer averages
+!              calculations. note "nvreg" is not used for tracer
+!              averages
 !     numreg = total number of regions ( = product of nhreg & nvreg)
 !              used for term balance calculations
 
@@ -22,10 +23,14 @@
 !     ncrows = number of calculated rows within the MW.
 !              (the remaining rows are buffer rows).
 
+!     rstd   = standard c14/c12 ratio
+
       integer lseg, nlatpr, nhreg, nvreg, numreg, nvar, nvarbh
       integer imtm1, kmm1, imtp1, imtm2, jmtp1, jmtm1, jmtm2, jscan
       integer kmp1, kmp2, imtkm, nwds, nkflds, nslab, ntmin2, ncrows
 
+      real rstd
+
       parameter (lseg=5, nlatpr=10)
 #if defined readrmsk
       parameter (nhreg=3, nvreg=1, numreg=nhreg*nvreg)
@@ -67,6 +72,9 @@
       parameter (ncrows = jmw - 2)
 # endif
 #endif
+#if defined uvic_carbon_14
+      parameter (rstd=1.176e-12)
+#endif
 
 #include "pconst.h"
 #include "stdunits.h"
