@@ -7,41 +7,78 @@
 !     imt    = number of grid points in the longitudinal direction
 !              (calculated points are from 2 through imt-1. End points
 !               are boundaries)
-
 !     jmt    = number of grid points (latitude rows) in the latitudinal
 !              direction (calculated points are from 2 through jmt-1.
 !              End points are boundaries)
-
 !     km     = number of grid points in the vertical direction
 !              (calculated points are from 1 through km)
-
 !     nt     = number of tracers (temperature, salinity, ...)
-
+!     nsrc   = number of tracer with sources
+!     kpzd   = depth for limited npzd model
+!     jmz    = size for "unrotated" zonal averages
+!     jmzm1  = jmz minus one
 !     mnisle = maximum number of islands (unconnected land masses)
-
 !     maxipp = maximum number of all island perimeter points
 !-----------------------------------------------------------------------
 # include "derived_options.h"
 
-      integer imt, jmt, km, nt, nat, jmz, jmzm1, mnisle, maxipp
-      integer nprocessors, jmw, jsmw, jemw, jextra
+      integer imt, jmt, km, nt, nsrc, kpzd, nat, jmz, jmzm1, mnisle
+      integer maxipp, nprocessors, jmw, jsmw, jemw, jextra
 
       parameter (imt=  102, jmt=  102, km= 19)
       parameter (nt=2
-#if defined uvic_npzd
-     $             +4
-#endif
 #if defined uvic_carbon
      $             +1
+# if defined uvic_carbon_14
+     $             +1
+# endif
+#endif
+#if defined uvic_cfc11
+     $             +1
+#endif
+#if defined uvic_cfc12
+     $             +1
+#endif
+#if defined uvic_alk
+     $             +1
+#endif
+#if defined uvic_o2
+     $             +1
+#endif
+#if defined uvic_npzd
+     $             +4
+# if defined uvic_nitrogen
+     $             +2
+# endif
 #endif
      $               )
-#if defined uvic_embm
-      parameter (nat=2
-# if defined uvic_carbon && defined uvic_carbon_co2_2d
-     $              +1
+      parameter (nsrc=0
+#if defined uvic_carbon
+     $               +1
+# if defined uvic_carbon_14
+     $               +1
 # endif
-     $, jmz=jmt, jmzm1=jmz-1)
 #endif
+#if defined uvic_alk
+     $               +1
+#endif
+#if defined uvic_o2
+     $               +1
+#endif
+#if defined uvic_npzd
+     $               +4
+# if defined uvic_nitrogen
+     $               +2
+# endif
+#endif
+     $                 )
+      parameter (kpzd=km)
+
+      parameter (nat=2
+#if defined uvic_carbon && defined uvic_carbon_co2_2d
+     $              +1
+#endif
+     $, jmz=jmt, jmzm1=jmz-1)
       parameter (mnisle=50, maxipp=5000)
 
 #if defined coarse_grained_parallelism && defined ramdrive
@@ -142,9 +179,10 @@
 #if defined uvic_mtlm
 ! POINTS = Maximum number of points in grid.
 ! STEPSM = Maximum number of timesteps in a day.
+! klmax = maximum ocean depth levels over which the land model can exist
 
-      integer POINTS, STEPSM
-      parameter (POINTS=3639, STEPSM=24)
+      integer POINTS, STEPSM, klmax
+      parameter (POINTS=4600, STEPSM=24, klmax=0)
 
 ! NNVG  = Number of non-vegetation surface types.
 ! NPFT  = Number of plant functional types.
