@@ -27,7 +27,7 @@
 !               number of "segtim".
 
 !     nmix    = number of time steps between mixing timesteps. used
-!               to damp timestep splitting due to centered leapfrog.
+!               to damp timestep splitting due to centred leapfrog.
 
 !     init    = (true,false)  indicates that this run is a
 !               (start from initial conditions, restart)
@@ -518,7 +518,7 @@
 !     Note the use of "ieomon" to key off the months.  The switch
 !     "testts" will be true whenever "eomon" is true.
 !     Also note that when an averaging switch is keyed off another
-!     switch, the switch inverval argument is not used, but is
+!     switch, the switch interval argument is not used, but is
 !     retained for consistency with the form of other averaging
 !     switches.
 !-----------------------------------------------------------------------
