@@ -13,19 +13,14 @@
 !     elev      = elevations (cm)
 !     flux      = downward flux accumulator (1=heat, 2=fresh water, ...)
 !     rh        = relative humidity (%/100)
-!     s_alb_z   = constant zonal snow free surface albedo (%/100)
-!     a_calb    = atmospheric coalbedo (%/100)
 !     tmsk      = tracer grid ocean mask (0 = land, 1 = ocean)
 !     umsk      = velocity grid ocean mask (0 = land, 1 = ocean)
 !     dn        = northward atmospheric tracer diffusivity
 !     de        = eastward atmospheric tracer diffusivity
 !     fcor      = Coriolis factor
-!     area_z    = areas for zonal averages
-!     wt_zonal  = weights for zonal averages
-!     yz        = latitudes for zonal averages
 !   heat fluxes
 !     solins    = incoming short wave radiation (g s-3)
-!     dnswr     = downward surface shortwave flux (g s-3)
+!     dnswr     = downward surface shortwave flux absorbed (g s-3)
 !     uplwr     = upward surface longwave flux (g s-3)
 !     upsens    = upward surface sensible heat flux (g s-3)
 !     upltnt    = upward surface latent heat flux (g s-3)
@@ -33,29 +28,21 @@
 !   fresh water fluxes
 !     precip    = precipitation (g cm-2 s-1)
 !     evap      = evaporation (g cm-2 s-1)
-!   moisture advection ("uvic_embm_adv_q")
-!     avgp      = segtim average precipitation (g cm-2 s-1)
-!     accp      = accumulator for precipitation (g cm-2 s-1)
-!   land model ("uvic_embm_land")
+!     disch     = discharge from continents (g cm-2 s-1)
+!   land model
 !     soilm     = soil moisture, as depth in bucket (g cm -2)
 !     runoff    = water runoff from continents (g cm-2 s-1)
 !     surf      = land surface temperature (C)
 !   annual average temperature ("uvic_embm_running_average")
 !     rtbar     = running average atmospheric temperature (C)
 !     atbar     = average temperature accumulator (C)
-!   windstress feedback ("uvic_embm_atress")
+!   wind feedback ("uvic_embm_awind")
+!     tbar      = climatological average atmospheric temperature (C)
 !     awx       = anomalous x component of wind (cm s-1)
 !     awy       = anomalous y component of wind (cm s-1)
-!     tbar      = climatological average atmospheric temperature (C)
-!     apress    = anomolous pressure (g cm-2 s-2)
+!     apress    = anomalous pressure (g cm-2 s-2)
 !   flux adjustment ("uvic_save_flxadj")
 !     flxadj    = flux adjustment
-!   constant boundary values ("time_mean_sbc_data")
-!     taux      = x component of wind stress data (dynes cm-2)
-!     tauy      = y component of wind stress data (dynes cm-2)
-!     wx        = x component of wind data (cm s-1)
-!     wy        = y component of wind data (cm s-1)
-!     ws        = wind speed data (cm s-1)
 !   indicies for atmospheric tracer array
 !     isat      = index for surface air temperature
 !     ishum     = index for surface specific humidity
@@ -68,82 +55,68 @@
       integer isat, ishum, ico2
       common /embm_i/ isat, ishum, ico2
 
-      real at, elev, flux, rh, s_alb_z, a_calb, tmsk, umsk, dn, de, fcor
-      real area_z, wt_zonal, yz, solins, dnswr, uplwr, upsens, upltnt
-      real outlwr, precip, evap, avgp, accp, soilm, runoff, surf, rtbar
-      real atbar, awx, awy, tbar, apress, flxadj, taux, tauy, wx, wy, ws
+      real at, elev, flux, rh, tmsk, umsk, dn, de, fcor, solins, dnswr
+      real uplwr, upsens, upltnt, outlwr, precip, evap, disch, soilm
+      real runoff, surf, rtbar, atbar, tbar, awx, awy, apress, flxadj
 
       common /embm_r/ at(imt,jmt,2,nat), elev(imt,jmt)
-#if defined uvic_ice_evp || defined uvic_embm_astress
+#if defined uvic_ice_evp || defined uvic_embm_awind
       common /embm_r/ flux(imt,jmt,nat+2), rh(imt,jmt)
 #else
       common /embm_r/ flux(imt,jmt,nat), rh(imt,jmt)
 #endif
-      common /embm_r/ s_alb_z(jmt), a_calb(imt,jmt)
-      common /embm_r/ tmsk(imt,jmt), umsk(imt,jmt)
-      common /embm_r/ dn(imt,jmt,nat), de(imt,jmt,nat)
-      common /embm_r/ fcor(imt,jmt), area_z(jmz), wt_zonal(imt,jmt)
-      common /embm_r/ yz(jmz), solins(imt,jmt), dnswr(imt,jmt)
-      common /embm_r/ uplwr(imt,jmt), upsens(imt,jmt), upltnt(imt,jmt)
-      common /embm_r/ outlwr(imt,jmt), precip(imt,jmt), evap(imt,jmt)
-#if defined uvic_embm_adv_q
-      common /embm_r/ avgp(imt,jmt), accp(imt,jmt)
-#endif
-#if defined uvic_embm_land
-      common /embm_r/ soilm(imt,jmt,2), runoff(imt,jmt), surf(imt,jmt)
-#endif
-#if defined uvic_embm_running_average || defined uvic_embm_astress || uvic_embm_calc_diffq
+      common /embm_r/ tmsk(imt,jmt), umsk(imt,jmt), dn(imt,jmt,nat)
+      common /embm_r/ de(imt,jmt,nat), fcor(imt,jmt), solins(imt,jmt)
+      common /embm_r/ dnswr(imt,jmt), uplwr(imt,jmt), upsens(imt,jmt)
+      common /embm_r/ upltnt(imt,jmt), outlwr(imt,jmt), precip(imt,jmt)
+      common /embm_r/ evap(imt,jmt), disch(imt,jmt)
+      common /embm_r/ soilm(imt,jmt,2), runoff(imt,jmt)
+      common /embm_r/ surf(imt,jmt)
+#if defined uvic_embm_running_average || defined uvic_embm_awind
       common /embm_r/ rtbar(imt,jmt), atbar(imt,jmt)
 #endif
-#if defined uvic_embm_astress
-      common /embm_r/ awx(imt,jmt), awy(imt,jmt), tbar(imt,jmt)
+#if defined uvic_embm_awind
+      common /embm_r/ tbar(imt,jmt), awx(imt,jmt), awy(imt,jmt)
       common /embm_r/ apress(imt,jmt)
 #endif
 #if defined uvic_save_flxadj
       common /embm_r/ flxadj(imt,jmt,2)
 #endif
-#if defined time_mean_sbc_data
-# if defined uvic_ice_evp || defined uvic_embm_astress
-      common /embm_r/ taux(imt,jmt), tauy(imt,jmt)
-# endif
-# if defined uvic_embm_adv_q && defined uvic_embm_astress
-      common /embm_r/ wx(imt,jmt), wy(imt,jmt)
-# endif
-# if defined uvic_embm_astress
-      common /embm_r/ ws(imt,jmt)
-# endif
-#endif
 
 #if defined time_averages
 !   time averaged arrays
 !     ta_at         = time averaged atmospheric tracers
-!     ta_outlwr     = time averaged outgoing longwave flux
-!     ta_uplwr      = time averaged upward longwave flux
+!     ta_solins     = time averaged incoming shortwave flux
+!     ta_arswr      = time averaged atmospheric reflected shortwave flux
 !     ta_dnswr      = time averaged downward shortwave flux
+!     ta_absin      = time averaged absorbed shortwave coming in
+!     ta_absout     = time averaged absorbed shortwave going out
+!     ta_uplwr      = time averaged upward longwave flux
 !     ta_upsens     = time averaged upward sensible heat flux
 !     ta_upltnt     = time averaged upward latent heat flux
-!     ta_solins     = time averaged incoming shortwave flux
+!     ta_outlwr     = time averaged outgoing longwave flux
 !     ta_precip     = time averaged precipitation
 !     ta_psno       = time averaged precipitation as snow
 !     ta_evap       = time averaged evaporation
-!     ta_s_calb     = time averaged surface coalbedo
-!     ta_a_calb     = time averaged atmospheric coalbedo
+!     ta_disch      = time averaged discharge
 !     ta_ws         = time averaged surface wind speed
 !     ta_runoff     = time averaged runoff
-!   bucket model ("uvic_embm_land")
 !     ta_soilm      = time averaged soil moisture
 !     ta_surf       = time averaged land surface temperature
 !   moisture advection ("uvic_embm_adv_q")
-!     ta_wx         = time averaged x component of wind
-!     ta_wy         = time averaged y component of wind
-!   windstress feedback ("uvic_embm_astress")
+!     ta_wx_q       = time averaged x component of wind
+!     ta_wy_q       = time averaged y component of wind
+!   moisture advection ("uvic_embm_adv_t")
+!     ta_wx_t       = time averaged x component of wind
+!     ta_wy_t       = time averaged y component of wind
+!   windstress feedback ("uvic_embm_awind")
 !     ta_awx        = time averaged x component of wind
 !     ta_awy        = time averaged y component of wind
 !     ta_rtbar      = time averaged running average temperature
-!     ta_apress     = time averaged anomolous pressure
+!     ta_apress     = time averaged anomalous pressure
 !   flux adjustment ("uvic_save_flxadj")
 !     ta_flxadj     = time averaged flux adjustment
-!   diffusivities ("uvic_save_diff")
+!   diffusivities ("uvic_embm_save_diff")
 !     ta_dn         = time averaged dn
 !     ta_de         = time averaged de
 !   flux of co2 ("uvic_carbon and uvic_carbon_co2_2d")
@@ -156,39 +129,41 @@
 !     ta_taux       = time averaged x component of wind stress
 !     ta_tauy       = time averaged x component of wind stress
 
-      real ta_at, ta_outlwr, ta_uplwr, ta_dnswr, ta_upsens, ta_upltnt
-      real ta_solins, ta_precip, ta_psno, ta_evap, ta_s_calb, ta_a_calb
-      real ta_ws, ta_soilm, ta_runoff, ta_surf, ta_wx, ta_wy, ta_awx
-      real ta_awy, ta_rtbar, ta_apress, ta_flxadj, ta_dn, ta_de
-      real ta_flxco2, ta_hflux, ta_sflux, ta_sss, ta_sst, ta_taux
-      real ta_tauy
+      real ta_at, ta_solins, ta_arswr, ta_dnswr, ta_absin, ta_absout
+      real ta_uplwr, ta_upsens, ta_upltnt, ta_outlwr, ta_precip
+      real ta_psno, ta_evap, ta_disch, ta_ws, ta_soilm, ta_runoff
+      real ta_surf, ta_wx_q, ta_wy_q, ta_wx_t, ta_wy_t, ta_awx, ta_awy
+      real ta_rtbar, ta_apress, ta_flxadj, ta_dn, ta_de, ta_flxco2
+      real ta_hflux, ta_sflux, ta_sss, ta_sst, ta_taux, ta_tauy
 
-      common /embm_r/ ta_at(imt,jmt,nat), ta_outlwr(imt,jmt)
-      common /embm_r/ ta_uplwr(imt,jmt), ta_dnswr(imt,jmt)
-      common /embm_r/ ta_upsens(imt,jmt), ta_upltnt(imt,jmt)
-      common /embm_r/ ta_solins(imt,jmt), ta_precip(imt,jmt)
-      common /embm_r/ ta_psno(imt,jmt), ta_evap(imt,jmt)
-      common /embm_r/ ta_s_calb(imt,jmt), ta_a_calb(imt,jmt)
+      common /embm_r/ ta_at(imt,jmt,nat), ta_solins(imt,jmt)
+      common /embm_r/ ta_arswr(imt,jmt), ta_dnswr(imt,jmt)
+      common /embm_r/ ta_absin(imt,jmt), ta_absout(imt,jmt)
+      common /embm_r/ ta_uplwr(imt,jmt), ta_upsens(imt,jmt)
+      common /embm_r/ ta_upltnt(imt,jmt), ta_outlwr(imt,jmt)
+      common /embm_r/ ta_precip(imt,jmt), ta_psno(imt,jmt)
+      common /embm_r/ ta_evap(imt,jmt), ta_disch(imt,jmt)
       common /embm_r/ ta_ws(imt,jmt), ta_runoff(imt,jmt)
-# if defined uvic_embm_land
       common /embm_r/ ta_soilm(imt,jmt), ta_surf(imt,jmt)
-# endif
 # if defined uvic_embm_adv_q
-      common /embm_r/ ta_wx(imt,jmt), ta_wy(imt,jmt)
+      common /embm_r/ ta_wx_q(imt,jmt), ta_wy_q(imt,jmt)
 # endif
-# if defined uvic_embm_astress
+# if defined uvic_embm_adv_t
+      common /embm_r/ ta_wx_t(imt,jmt), ta_wy_t(imt,jmt)
+# endif
+# if defined uvic_embm_awind
       common /embm_r/ ta_awx(imt,jmt), ta_awy(imt,jmt)
       common /embm_r/ ta_rtbar(imt,jmt), ta_apress(imt,jmt)
 # endif
 # if defined uvic_save_flxadj
       common /embm_r/ ta_flxadj(imt,jmt,2)
 # endif
-# if defined uvic_save_diff
+# if defined uvic_embm_save_diff
       common /embm_r/ ta_dn(imt,jmt,nat), ta_de(imt,jmt,nat)
 # endif
-#if defined uvic_carbon && defined uvic_carbon_co2_2d
+# if defined uvic_carbon && defined uvic_carbon_co2_2d
       common /embm_r/ ta_flxco2(imt,jmt)
-#endif
+# endif
 # if !defined uvic_mom
       common /embm_r/ ta_hflux(imt,jmt), ta_sflux(imt,jmt)
       common /embm_r/ ta_sss(imt,jmt), ta_sst(imt,jmt)
