@@ -63,7 +63,7 @@
 # endif
 # if defined uvic_embm_mgrid
 !     for mgrid routine storage is by compass coefficient
-!     ap, an, as, ae, aw = center, north, south, east, and west coef
+!     ap, an, as, ae, aw = centre, north, south, east, and west coef
 !     ie. ap*xp = an*xn + as*xs + ae*xe + aw*xw + bp
 
       integer levelin, levelout
@@ -101,14 +101,14 @@
 !     for ESSL DSRIS routine storage is by rows
 !     ia     = index of ar for the first entry of a row
 !     ja     = column index
-!     iparm  = integer solver paramerters
+!     iparm  = integer solver parameters
 !     nelm   = number of nonzero elements in A
 !     naux1  = size of work space 1 (may change if solver type changed)
 !     naux2  = size of work space 2 (may change if solver type changed)
 !     ar     = coefficient matrix (stored form of A)
 !     aux1   = work space 1
 !     aux2   = work space 2
-!     rparm  = real solver paramerters
+!     rparm  = real solver parameters
 
       integer naux1, naux2
       parameter (nelm = 3*nord + 2*iimtm2*(jjmtm2 - 1))
@@ -127,11 +127,11 @@
 !     for storage is by rows
 !     ia     = index of ar for the first entry of a row
 !     ja     = column index
-!     ipar   = integer solver paramerters
+!     ipar   = integer solver parameters
 !     nelm   = number of nonzero elements in A
 !     nwork  = size of work space (may change if solver type changed)
 !     ar     = coefficient matrix (stored form of A)
-!     fpar   = real solver paramerters
+!     fpar   = real solver parameters
 !     work   = work space
 
       integer nwork
