@@ -1,10 +1,8 @@
 !========================= include file "veg.h" ========================
 #include "derived_options.h"
-!   variables for the vegetation option ("uvic_embm_veg")
+!   variables for the vegetation data
 
-!   vegetation ("uvic_embm_veg")
-
-!   UVic Vegetation types
+!   Vegetation types
 !     1 = tropical forest
 !     2 = temperate/boreal forest
 !     3 = grass
@@ -22,8 +20,8 @@
 !     veg_dalt  = dalton number over land
 !     idesert   = index for desert
 !     icrops    = index for cropland
-!   land use ("uvic_embm_crops")
-!     crops     = cropland extent as percentage of gridcell
+!   land use ("uvic_embm_cropdata")
+!     crops     = cropland extent as percentage of grid cell
 !     crops_yr  = year for crops (1700 to 1992)
 
       integer nveg, iveg, idesert, icrops
@@ -32,12 +30,10 @@
       parameter (nveg=7)
       common /veg_r/ veg_rl(nveg), veg_alb(nveg), veg_rs(nveg)
       common /veg_r/ veg_smd(nveg)
-#if defined uvic_embm_veg
       common /veg_i/ iveg(imt,jmt), idesert, icrops
-# if defined uvic_embm_crops
+#if defined uvic_embm_cropdata
       common /veg_r/ crops(imt,jmt,1:3), crops_yr
       common /veg_r/ veg_dalt(imt,jmt)
-# else
+#else
       common /veg_r/ veg_dalt(nveg)
-# endif
 #endif
