@@ -23,8 +23,8 @@
 !     tbar      = first moment of tracer at "tau"
 !     travar    = variance = second moment of tracer about mean at "tau"
 !     isot1     = starting i index of section 1 for max/min overturning
-!     ieot1     = ending i index of section 2 for max/min overturning
-!     isot2     = starting i index of section 1 for max/min overturning
+!     ieot1     = ending i index of section 1 for max/min overturning
+!     isot2     = starting i index of section 2 for max/min overturning
 !     ieot2     = ending i index of section 2 for max/min overturning
 !     jsot      = starting j index for max/min overturning
 !     jeot      = ending j index for max/min overturning
@@ -47,29 +47,46 @@
       common /cdiag/ t_slh(2:imtm1,2:jmtm1,km,2)
 # endif
 
-!     ntatio    = number of time averaged time step integrals
-!     tai_ek    = average integrated kinetic energy
-!     tai_t     = average integrated temperature
-!     tai_s     = average integrated salinity
-!     tai_tvar  = average integrated second moment of temperature
-!     tai_svar  = average integrated second moment of salinity
-!     tai_dt    = average integrated rate of change of temperature
-!     tai_ds    = average integrated rate of change of salinity
-!     tai_scan  = average scans for ocean solver
-!     tai_otmax = average maximum overturning
-!     tai_otmin = average minimum overturning
-!     tai_slh   = average integrated sea level height
-!     tai_dic   = average dic
-!     tai_n     = average nutrients
-!     tai_p     = average phytoplankton
-!     tai_z     = average zooplankton
-!     tai_d     = average detritus
-!     tai_npzd  = average n+p+z+d
+!     ntatio        = number of time averaged time step integrals
+!     tai_ek        = average integrated kinetic energy
+!     tai_t         = average integrated temperature
+!     tai_s         = average integrated salinity
+!     tai_tvar      = average integrated second moment of temperature
+!     tai_svar      = average integrated second moment of salinity
+!     tai_dt        = average integrated rate of change of temperature
+!     tai_ds        = average integrated rate of change of salinity
+!     tai_scan      = average scans for ocean solver
+!     tai_otmax     = average maximum overturning
+!     tai_otmin     = average minimum overturning
+!     tai_slh       = average integrated sea level height
+!     tai_hflx      = average heat flux
+!     tai_sflx      = average salt flux
+!     tai_dic       = average carbon
+!     tai_dicflx    = average carbon flux
+!     tai_alk       = average alkalinity
+!     tai_o2        = average oxygen
+!     tai_o2flx     = average oxygen flux
+!     tai_po4       = average phosphate
+!     tai_p         = average phytoplankton
+!     tai_z         = average zooplankton
+!     tai_d         = average detritus
+!     tai_no3       = average nitrate
+!     tai_di        = average diazotrophs
+!     tai_c14       = average carbon 14
+!     tai_dc14      = average delta carbon 14
+!     tai_c14flx    = average carbon 14 flux
+!     tai_cfc11     = average CFC11
+!     tai_cfc11flx  = average CFC11 flux
+!     tai_cfc12     = average CFC12
+!     tai_cfc12flx  = average CFC12 flux
 
       common /cdiagi/ ntatio
       common /cdiag/ tai_ek, tai_t, tai_s, tai_tvar, tai_svar, tai_dt
       common /cdiag/ tai_ds, tai_scan, tai_otmax, tai_otmin, tai_slh
-      common /cdiag/ tai_dic, tai_n, tai_p, tai_z, tai_d, tai_npzd
+      common /cdiag/ tai_hflx, tai_sflx, tai_dic, tai_dicflx, tai_alk
+      common /cdiag/ tai_o2, tai_o2flx, tai_po4, tai_p, tai_z, tai_d
+      common /cdiag/ tai_no3, tai_di, tai_c14, tai_dc14, tai_c14flx
+      common /cdiag/ tai_cfc11, tai_cfc11flx, tai_cfc12, tai_cfc12flx
 #endif
 #if defined energy_analysis
 
