@@ -1,14 +1,21 @@
 !====================== include file "diaga.h" =========================
 
 !     variables used for computing diagnostics:
+#if defined uvic_carbon && defined uvic_carbon_14
 
+!     dc14bar  = total volume weighted delta c14
+!     dc14     = delta c14
+
+      common /cdiaga_r/ dc14bar, dc14(imt,km,jsmw:jemw)
+#endif
 #if defined uvic_save_convection
 
-!     totalk = total number of levels involved in convection
-!     vdepth = ventilation depth
-!     pe     = potential energy lost due to explicit convection
+!     totalk   = total number of levels involved in convection
+!     vdepth   = ventilation depth (cm)
+!     pe       = potential energy lost due to explicit convection (g/s2)
 
-      common /exconv/ totalk(imt,jmt), vdepth(imt,jmt), pe(imt,jmt)
+      common /cdiaga_r/ totalk(imt,jsmw:jemw), vdepth(imt,jsmw:jemw)
+      common /cdiaga_r/ pe(imt,jsmw:jemw)
 #endif
 #if defined save_convection
 
@@ -17,8 +24,8 @@
 !                 explicit convection. set to epsln over land
 !                 for use in identifying land cells
 
-      common /exconv/ excnv0(imt,km, jsmw:jemw)
-      common /exconv/ excnv1(imt,km,jsmw:jemw)
+      common /cdiaga_r/ excnv0(imt,km, jsmw:jemw)
+      common /cdiaga_r/ excnv1(imt,km,jsmw:jemw)
 #endif
 #if defined save_mixing_coeff
 
@@ -26,7 +33,7 @@
 !     cn = ceoff on north face of cell (1 is for momentum, 2 for tracers)
 !     cb = ceoff on bottom face of cell(1 is for momentum,2 for tracers)
 
-      common /mixcoef/ ce(imt,km,jsmw:jemw,2)
-      common /mixcoef/ cn(imt,km,jsmw:jemw,2)
-      common /mixcoef/ cb(imt,km,jsmw:jemw,2)
+      common /cdiaga_r/ ce(imt,km,jsmw:jemw,2)
+      common /cdiaga_r/ cn(imt,km,jsmw:jemw,2)
+      common /cdiaga_r/ cb(imt,km,jsmw:jemw,2)
 #endif
