@@ -4,7 +4,6 @@
 
 !     based on code by: R. C. Pacanowski
 !=======================================================================
-#if !defined uvic_no_statfunc
 
       T_i(i,k,j,n,ip) = t(i+ip,k,j,n,taum1)
       T_j(i,k,j,n,jp) = t(i,k,j+jp,n,taum1)
@@ -20,28 +19,28 @@
 !     advective terms
 !-----------------------------------------------------------------------
 
-# if defined linearized_advection
+#if defined linearized_advection
       ADV_Tx(i,k,j) = 0.0
       ADV_Ty(i,k,j,jrow,n) = 0.0
       ADV_Tz(i,k,j) = (adv_fb(i,k-1,j) - adv_fb(i,k,j))*dzt2r(k)
-# else
+#else
       ADV_Tx(i,k,j) = (adv_fe(i,k,j) - adv_fe(i-1,k,j))*cstdxt2r(i,j)
-#  if defined fourth_order_tracer_advection || defined quicker
+# if defined fourth_order_tracer_advection || defined quicker
       ADV_Ty(i,k,j,jrow,n) = (adv_f4n(i,k,j,n) - adv_f4n(i,k,j-1,n))
      &  *cstdyt2r(jrow)
-#  else
-#   if defined fct || defined isoneutralmix
+# else
+#  if defined fct || defined isoneutralmix
       ADV_Ty(i,k,j,jrow,n) = (adv_fn(i,k,j) - adv_fn(i,k,j-1))
      &  *cstdyt2r(jrow)
-#   else
+#  else
       ADV_Ty(i,k,j,jrow,n) = (adv_vnt(i,k,j)*(t(i,k,j,n,tau)
      &  + t(i,k,j+1,n,tau)) - adv_vnt(i,k,j-1)*(t(i,k,j-1,n,tau)
      &  + t(i,k,j,n,tau)))*cstdyt2r(jrow)
-#   endif
 #  endif
-      ADV_Tz(i,k,j) = (adv_fb(i,k-1,j) - adv_fb(i,k,j))*dzt2r(k)
 # endif
-# if defined gent_mcwilliams && defined isopycmix
+      ADV_Tz(i,k,j) = (adv_fb(i,k-1,j) - adv_fb(i,k,j))*dzt2r(k)
+#endif
+#if defined gent_mcwilliams && defined isopycmix
 
 !     gent_mcwilliams isopycnal advective terms simulating the effect
 !     of eddies on the isopycnals
@@ -53,7 +52,7 @@
      &  *(t(i,k,j+1,n,taum1) + t(i,k,j,n,taum1)) - adv_vntiso(i,k,j-1)
      &  *(t(i,k,j,n,taum1) + t(i,k,j-1,n,taum1)))
       ADV_Tziso(i,k,j) = dzt2r(k)*(adv_fbiso(i,k-1,j)-adv_fbiso(i,k,j))
-# endif
+#endif
 
 !-----------------------------------------------------------------------
 !     diffusive terms
@@ -66,28 +65,27 @@
 
 !     meridional component
 
-# if defined consthmix && !defined biharmonic && !defined isopycmix
-#  if defined bryan_lewis_horizontal
+#if defined consthmix && !defined biharmonic && !defined isopycmix
+# if defined bryan_lewis_horizontal
       DIFF_Ty(i,k,j,jrow,n) = ahc_north(jrow,k)*tmask(i,k,j+1)
      &  *(t(i,k,j+1,n,taum1) - t(i,k,j,n,taum1)) - ahc_south(jrow,k)
      &  *tmask(i,k,j-1)*(t(i,k,j,n,taum1) - t(i,k,j-1,n,taum1))
-#  else
+# else
       DIFF_Ty(i,k,j,jrow,n) = ahc_north(jrow)*tmask(i,k,j+1)
      &  *(t(i,k,j+1,n,taum1) - t(i,k,j,n,taum1)) - ahc_south(jrow)
      &  *tmask(i,k,j-1)*(t(i,k,j,n,taum1) - t(i,k,j-1,n,taum1))
-#  endif
-# else
+# endif
+#else
       DIFF_Ty(i,k,j,jrow,n) = (diff_fn(i,k,j  )*tmask(i,k,j+1)
      &  - diff_fn(i,k,j-1)*tmask(i,k,j-1))*cstdytr(jrow)
-# endif
+#endif
 
 !     vertical component
 
       DIFF_Tz(i,k,j) = (diff_fb(i,k-1,j) - diff_fb(i,k,j))*dztr(k)
-# if defined implicitvmix || defined isopycmix || defined isoneutralmix || defined redi_diffusion
+#if defined implicitvmix || defined isopycmix || defined isoneutralmix || defined redi_diffusion
      &  *(c1-aidif)
-# endif
-# if defined isopycmix || defined isoneutralmix
+#endif
+#if defined isopycmix || defined isoneutralmix
      &  + (diff_fbiso(i,k-1,j) - diff_fbiso(i,k,j))*dztr(k)
-# endif
 #endif
