@@ -15,7 +15,7 @@
 !     A memory window "MW" is constructed to hold a group of "jmw"
 !     adjacent latitude rows of prognostic quantities from disks "tau-1"
 !     and "tau".  Parameter "jmw" controls the size of the MW and can be
-!     set anywhere from a miminum of three latitude rows to all "jmt"
+!     set anywhere from a minimum of three latitude rows to all "jmt"
 !     latitudes.  In addition, the MW holds diagnostic quantities
 !     (density, hydrostatic pressure gradients, and advective
 !     velocities) along with work arrays for constructing intermediate
@@ -44,7 +44,7 @@
 !     re-calculate the three dimensional land/sea mask arrays). After a
 !     time step has finished, time level pointers on the next time step
 !     are simply updated to reflect where the "tau-1", "tau" and "tau+1"
-!     data is. In principle, MOM 2 can be viewed as a sucession of
+!     data is. In principle, MOM 2 can be viewed as a succession of
 !     triply nested do loops with parallelism exposed at the do loop
 !     level (fine grained parallelism) as opposed to the latitude row
 !     level (coarse grained parallelism) of MOM 1. This structure
@@ -54,7 +54,7 @@
 
 !     based on code by: R. C. Pacanowski
 !=======================================================================
-
+# include "derived_options.h"
 #if defined coarse_grained_parallelism
 !DIR$ TASKCOMMON mw
 !CDIR TASKLOCAL (/mw/)
@@ -100,20 +100,53 @@
       common /mw/ u(imt,km,jmw,2,-1:1), t(imt,km,jmw,nt,-1:1)
 
 !     indicies for ocean tracer array
-!       itemp = index for temperature
-!       isalt = index for  salinity
-!       idic  = index for  disolved inorganic carbon
-!       inutr = index for  nutrients
-!       iphyt = index for  phytoplankton
-!       izoop = index for  zooplankton
-!       idetr = index for  detritus
-!       mapt  = map for ocean tracer names
+!       itemp  = index for temperature
+!       isalt  = index for salinity
+!       idic   = index for dissolved inorganic carbon
+!       ic14   = index for carbon 14
+!       icfc11 = index for cfc11
+!       icfc12 = index for cfc12
+!       ialk   = index for alkalinity
+!       ipo4   = index for phosphate
+!       iphyt  = index for phytoplankton
+!       izoop  = index for zooplankton
+!       idetr  = index for detritus
+!       io2    = index for oxygen
+!       ino3   = index for nitrate
+!       idiaz  = index for diazotrophs
+!       mapt   = map for ocean tracer names
 
-      character(10) :: mapt(nt)
-      common /mw_c/ mapt
+      character(10) :: mapt
+      common /mw_c/ mapt(nt)
 
-      integer itemp, isalt, idic, inutr, iphyt, izoop, idetr
-      common /mw_i/ itemp, isalt, idic, inutr, iphyt, izoop, idetr
+      integer itemp, isalt, idic, ic14, icfc11, icfc12, ialk, ipo4
+      integer iphyt, izoop, idetr, io2, ino3, idiaz
+      common /mw_i/ itemp, isalt, idic, ic14, icfc11, icfc12, ialk
+      common /mw_i/ ipo4, iphyt, izoop, idetr, io2, ino3, idiaz
+
+!     indicies for ocean tracer source array
+!       istemp  = index for temperature
+!       issalt  = index for salinity
+!       isdic   = index for carbon
+!       isc14   = index for carbon 14
+!       isalk   = index for alkalinity
+!       ispo4   = index for phosphate
+!       isphyt  = index for phytoplankton
+!       iszoop  = index for zooplankton
+!       isdetr  = index for detritus
+!       itrc    = index of tracer sources for all tracers (0 = no source)
+!       mapst   = map for ocean tracer source names
+
+      character(10) :: mapst
+      common /mw_c/ mapst(nt)
+
+      integer itrc
+      common /mw_i/ itrc(nt)
+
+      integer istemp, issalt, isdic, isc14, isalk, ispo4, isphyt
+      integer iszoop, isdetr, iso2, isno3, isdiaz
+      common /mw_i/ istemp, issalt, isdic, isc14,isalk, ispo4, isphyt
+      common /mw_i/ iszoop, isdetr, iso2, isno3, isdiaz
 
 !-----------------------------------------------------------------------
 !     MW arrays for diagnostic equations and workspace:
@@ -128,7 +161,7 @@
 !     adv_vbt  = advective velocity on the bottom face of a "T" cell
 !     adv_vbu  = advective velocity on the bottom face of a "u" cell
 
-!     rho      = density at center of a "T" cell in units of gm/cm**3
+!     rho      = density at centre of a "T" cell in units of gm/cm**3
 !                note: there is an arbitrary constant which is only a
 !                function of depth in "rho". It is related to
 !                subtracting a reference level density for purposes of
@@ -219,18 +252,18 @@
       common /mw/ csudxtr(imt,jsmw:jmw)
       common /mw/ csudxu2r(imt,jsmw:jmw),am_csudxtr(imt,jsmw:jmw)
 
-!     these variables are either constant or globally dimensiond by
+!     these variables are either constant or globally dimensioned by
 !     "jmt", so they do not need to be moved as the MW moves northward
 
 !     advmet = coeff for metric advection.
-!     cori   = coriolis parameter for velocity component "n"
+!     cori   = Coriolis parameter for velocity component "n"
 
       common /advec/ advmet(jmt,2)
 
       common /coriol/ cori(imt,jmt,2)
 #if defined equivalence_mw
 
-!     if the MW storage is > workspace for the poisson solvers, then
+!     if the MW storage is > workspace for the Poisson solvers, then
 !     the poisson solver workspace may be equivalenced to the MW to
 !     save space. this is not allowed when the MW is opened all the way
 !     amount of savings is dependent on problem size
@@ -243,7 +276,7 @@
 
 #if defined linearized_advection || defined equatorial_thermocline
 
-!     initial temperature profile independent of latitiude and longitude
+!     initial temperature profile independent of latitude and longitude
 
       common /profile/ tbarz(km,nt)
 #endif
