@@ -6,27 +6,31 @@
 
       parameter (imtav=imt, jmtav=jmt-2, kmav=km)
 #if defined isopycmix && defined gent_mcwilliams && defined time_averages
-
-!     ta_vetiso = time averaged adv_vetiso
-!     ta_vntiso = time averaged adv_vntiso
-!     ta_vbtiso = time averaged adv_vbtiso
-
       common /ta_gm_r/ ta_vetiso(imt,km,jmt), ta_vntiso(imt,km,jmt)
       common /ta_gm_r/ ta_vbtiso(imt,km,jmt)
 #endif
+#if defined uvic_carbon_14
+      common /ta_dc14/ ta_dc14(imt,km,jmt)
+#endif
+#if defined uvic_kv_out
+      common /ta_kv/ ta_diff_cbt(imt,km,jmt)
+#endif
 #if defined uvic_npzd_out
-
-!     ta_rnpp = time averaged rnpp
-!     ta_rgraz = time averaged rgraz
-!     ta_rmorp = time averaged rmorp
-!     ta_rmorz = time averaged rmorz
-!     ta_rremi = time averaged rremi
-!     ta_rexcr = time averaged rexcr
-
-      common /ta_npzd_r/ ta_rnpp(imt,km,jmt), ta_rgraz(imt,km,jmt)
-      common /ta_npzd_r/ ta_rmorp(imt,km,jmt), ta_rmorz(imt,km,jmt)
-      common /ta_npzd_r/ ta_rremi(imt,km,jmt), ta_rexcr(imt,km,jmt)
+      common /ta_npzd_r/ ta_rnpp(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rgraz(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rmorp(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rmorpt(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rmorz(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rexcr(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rremi(imt,km,jmt)
       common /ta_npzd_r/ ta_rexpo(imt,km,jmt)
+# if defined uvic_nitrogen
+      common /ta_npzd_r/ ta_rnpp_D(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rgraz_D(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rmorp_D(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rnfix(imt,kpzd,jmt)
+      common /ta_npzd_r/ ta_rdeni(imt,km,jmt)
+# endif
 #endif
 #if defined uvic_save_convection
       common /ta_conv_i/ nta_conv
