@@ -9,11 +9,19 @@
       real data(imt,jmt), value
       integer mask(imt,jmt), i, j, k, imt, jmt
 
-      do j=1,jmt
-        do i=1,imt
-          if (mask(i,j) .lt. k) data(i,j) = value
+      if (k .ge. 0) then
+        do j=1,jmt
+          do i=1,imt
+            if (mask(i,j) .lt. k) data(i,j) = value
+          enddo
         enddo
-      enddo
+      else
+        do j=1,jmt
+          do i=1,imt
+            if (mask(i,j) .ge. -k) data(i,j) = value
+          enddo
+        enddo
+      endif
 
       return
       end
@@ -595,12 +603,12 @@
 !     check for weighting error
           if (abs(wtn) .gt. onep .or. abs(wts) .gt. onep .or.
      &        abs(wte) .gt. onep .or. abs(wtw) .gt. onep) then
-            print*, 'Wieghting error: i, j, wtn, wts, wte, wtw '
+            print*, 'Weighting error: i, j, wtn, wts, wte, wtw '
      &,                 i,j,wtn,wts,wte,wtw
             stop 'rot_intrp_sclr'
           endif
 
-!     set weights to zero for bad data values and normalise the good
+!     set weights to zero for bad data values and normalize the good
 
           wtne = wtn*wte
           if (abs(tg(ie,jn)) .ge. abad) wtne = 0.
@@ -612,10 +620,30 @@
           if (abs(tg(iw,js)) .ge. abad) wtsw = 0.
           if (near .ne. 0) then
             wt = max(wtne, wtse, wtnw, wtsw)
-            if (wtne .ne. wt) wtne = 0.
-            if (wtse .ne. wt) wtse = 0.
-            if (wtnw .ne. wt) wtnw = 0.
-            if (wtsw .ne. wt) wtsw = 0.
+            if (wtne .eq. wt) then
+              wtne = 1.
+              wtse = 0.
+              wtnw = 0.
+              wtsw = 0.
+            endif
+            if (wtse .eq. wt) then
+              wtne = 0.
+              wtse = 1.
+              wtnw = 0.
+              wtsw = 0.
+            endif
+            if (wtnw .eq. wt) then
+              wtne = 0.
+              wtse = 0.
+              wtnw = 1.
+              wtsw = 0.
+            endif
+            if (wtsw .eq. wt) then
+              wtne = 0.
+              wtse = 0.
+              wtnw = 0.
+              wtsw = 1.
+            endif
           endif
           wt = wtne + wtse + wtnw + wtsw
 
